@@ -7,6 +7,7 @@ Refer to sub-class for typical usage examples.
 """
 from __future__ import annotations
 
+from abc import ABC, abstractmethod
 from typing import Any, List, Optional
 
 from concepttordf import Concept
@@ -253,7 +254,7 @@ class InformationModel(Resource):
             self._g.add((URIRef(self.identifier), DCT.license, _licensedocument))
 
 
-class ModelElement:
+class ModelElement(ABC):
     """A class representing a modelldcatno:ModelElement."""
 
     __slots__ = (
@@ -273,6 +274,7 @@ class ModelElement:
     _has_property: List[ModelProperty]
     _subject: Concept
 
+    @abstractmethod
     def __init__(self) -> None:
         """Inits an object with default values."""
         self._type = MODELLDCATNO.ModelElement
@@ -328,6 +330,7 @@ class ModelElement:
         """Set for has_property."""
         self._has_property = has_property
 
+    @abstractmethod
     def to_rdf(self, format: str = "turtle", encoding: Optional[str] = "utf-8") -> str:
         """Maps the modelelement to rdf.
 
@@ -335,10 +338,7 @@ class ModelElement:
             format: a valid format. Default: turtle
             encoding: the encoding to serialize into
 
-        Returns:
-            a rdf serialization as a string according to format.
         """
-        return self._to_graph().serialize(format=format, encoding=encoding)
 
     def _to_graph(
         self, type: str = MODELLDCATNO.ModelElement, selfobject: Any = None
@@ -360,28 +360,20 @@ class ModelElement:
         self._g.bind("skos", SKOS)
         self._g.bind("xsd", XSD)
 
-        if selfobject:
-            _self = selfobject
-
-        elif getattr(self, "identifier", None):
-            _self = URIRef(self.identifier)
-
-        else:
-            _self = BNode()
-        self._g.add((_self, RDF.type, type))
+        self._g.add((selfobject, RDF.type, type))
 
         if getattr(self, "title", None):
             for key in self.title:
                 self._g.add(
                     (
-                        _self,
+                        selfobject,
                         DCT.title,
                         Literal(self.title[key], lang=key),
                     )
                 )
 
         if getattr(self, "dct_identifier", None):
-            self._g.add((_self, DCT.identifier, Literal(self._dct_identifier)))
+            self._g.add((selfobject, DCT.identifier, Literal(self._dct_identifier)))
 
         if getattr(self, "subject", None):
 
@@ -390,10 +382,10 @@ class ModelElement:
             for _s, p, o in self.subject._to_graph().triples((None, None, None)):
                 self._g.add((_subject, p, o))
 
-            self._g.add((_self, DCT.subject, _subject))
+            self._g.add((selfobject, DCT.subject, _subject))
 
         if getattr(self, "has_property", None):
-            self._has_property_to_graph(_self)
+            self._has_property_to_graph(selfobject)
 
         return self._g
 
@@ -1805,6 +1797,8 @@ class CodeElement:
         "_notation",
         "_in_scheme",
         "_top_concept_of",
+        "_altlabel",
+        "_definition",
     )
 
     _identifier: URI
@@ -1816,6 +1810,8 @@ class CodeElement:
     _notation: str
     _in_scheme: List[CodeList]
     _top_concept_of: List[CodeList]
+    _altlabel: dict
+    _definition: dict
 
     def __init__(self) -> None:
         """Inits an object with default values."""
@@ -1891,6 +1887,26 @@ class CodeElement:
         """Set for top_concept_of."""
         self._top_concept_of = top_concept_of
 
+    @property
+    def altlabel(self: CodeElement) -> dict:
+        """Get for altlabel."""
+        return self._altlabel
+
+    @altlabel.setter
+    def altlabel(self: CodeElement, altlabel: dict) -> None:
+        """Set for altlabel."""
+        self._altlabel = altlabel
+
+    @property
+    def definition(self: CodeElement) -> dict:
+        """Get for definition."""
+        return self._definition
+
+    @definition.setter
+    def definition(self: CodeElement, definition: dict) -> None:
+        """Set for definition."""
+        self._definition = definition
+
     def to_rdf(
         self: CodeElement, format: str = "turtle", encoding: Optional[str] = "utf-8"
     ) -> str:
@@ -1933,6 +1949,8 @@ class CodeElement:
         self._subject_to_graph(_self)
         self._in_scheme_to_graph(_self)
         self._top_concept_of_to_graph(_self)
+        self._altlabel_to_graph(_self)
+        self._definition_to_graph(_self)
 
         return self._g
 
@@ -1999,3 +2017,29 @@ class CodeElement:
                     )
 
                 self._g.add((_self, SKOS.topConceptOf, _top_concept_of))
+
+    def _altlabel_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "altlabel", None):
+
+            for key in self.altlabel:
+                self._g.add(
+                    (
+                        _self,
+                        SKOS.altLabel,
+                        Literal(self.altlabel[key], lang=key),
+                    )
+                )
+
+    def _definition_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "definition", None):
+
+            for key in self.definition:
+                self._g.add(
+                    (
+                        _self,
+                        SKOS.definition,
+                        Literal(self.definition[key], lang=key),
+                    )
+                )
